diff --git a/thunar/thunar-transfer-job.c b/thunar/thunar-transfer-job.c
index 78751b219983d897f2420d0ef3d6dcd8ed38318b..83e4566f665c404aff04f6c9b2c7dc4f34c7acaf 100644
--- a/thunar/thunar-transfer-job.c
+++ b/thunar/thunar-transfer-job.c
@@ -145,8 +145,8 @@ thunar_transfer_job_progress (goffset  current_num_bytes,
       new_percentage = (job->total_progress * 100.0) / job->total_size;
 
       /* notify callers about the progress only if we have advanced by
-       * at least 0.05 percent since the last signal emission */
-      if (new_percentage > (job->previous_percentage + 0.05))
+       * at least 0.01 percent since the last signal emission */
+      if (new_percentage >= (job->previous_percentage + 0.01))
         {
           /* emit the percent signal */
           exo_job_percent (EXO_JOB (job), new_percentage);